'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

function useTimeout() {
    var _a = react.useState(null), to = _a[0], setTo = _a[1];
    react.useEffect(function () {
        return function () {
            if (to)
                clearTimeout(to);
        };
    }, [to]);
    return function (callback, ms) {
        var to = setTimeout(callback, ms);
        setTo(to);
    };
}
function useToggle(ref) {
    var _a = react.useState(false), state = _a[0], setState = _a[1];
    useOutsideClick(function () { return setState(false); }, ref);
    return [
        state,
        function (bool) {
            if (bool)
                setState(bool);
            else
                setState(!state);
        },
    ];
}
function useWindowEventListener(type, callback, options) {
    react.useEffect(function () {
        if (options && typeof options !== "boolean" && options.initExecute)
            callback();
        window.addEventListener(type, callback, options);
        return function () { return window.removeEventListener(type, callback, options); };
    }, [callback]);
}
function useDocumentEventListener(type, callback, options) {
    react.useEffect(function () {
        if (options && typeof options !== "boolean" && options.initExecute)
            callback();
        document.addEventListener(type, callback, options);
        return function () { return document.removeEventListener(type, callback, options); };
    }, [callback]);
}
function useEventListener(eventName, handler, element) {
    // Create a ref that stores handler
    var savedHandler = react.useRef();
    react.useEffect(function () {
        // Define the listening target
        var targetElement = (element === null || element === void 0 ? void 0 : element.current) || window;
        if (!(targetElement && targetElement.addEventListener)) {
            return;
        }
        // Update saved handler if necessary
        if (savedHandler.current !== handler) {
            savedHandler.current = handler;
        }
        // Create event listener that calls handler function stored in ref
        var eventListener = function (event) {
            // eslint-disable-next-line no-extra-boolean-cast
            if (!!(savedHandler === null || savedHandler === void 0 ? void 0 : savedHandler.current)) {
                savedHandler.current(event);
            }
        };
        targetElement.addEventListener(eventName, eventListener);
        // Remove event listener on cleanup
        return function () {
            targetElement.removeEventListener(eventName, eventListener);
        };
    }, [eventName, element, handler]);
}
function useOutsideClick(callback, ref) {
    var handleOutsideClick = react.useCallback(function (e) {
        if (ref.current && !ref.current.contains(e.target))
            callback(e);
    }, [callback, ref]);
    react.useEffect(function () {
        document.addEventListener("mousedown", handleOutsideClick);
        return function () {
            document.removeEventListener("mousedown", handleOutsideClick);
        };
    }, [handleOutsideClick]);
}
function useWindowSize() {
    var isClient = typeof window === "object";
    function getSize() {
        return {
            width: isClient ? window.innerWidth : undefined,
            height: isClient ? window.innerHeight : undefined,
            isSemi: window.innerWidth <= 1560,
        };
    }
    var _a = react.useState(getSize), windowSize = _a[0], setWindowSize = _a[1];
    react.useEffect(function () {
        if (!isClient)
            return;
        function handleResize() {
            setWindowSize(getSize());
        }
        window.addEventListener("resize", handleResize);
        return function () { return window.removeEventListener("resize", handleResize); };
        // eslint-disable-next-line
    }, []);
    return windowSize;
}
function useQuadrant(parentRef, cwidth, cheight, defaultQuadrant) {
    var _a = react.useState(defaultQuadrant), quadrant = _a[0], setQuadrant = _a[1];
    var _b = useWindowSize(), width = _b.width, height = _b.height;
    react.useLayoutEffect(function () {
        if (parentRef.current && width && height) {
            var newQuadrant = defaultQuadrant;
            var _a = parentRef.current.getBoundingClientRect(), x = _a.x, y = _a.y;
            if (x + cwidth > width) {
                if (newQuadrant === 1)
                    newQuadrant = 4;
                else if (newQuadrant === 2)
                    newQuadrant = 3;
            }
            if (y + cheight > height) {
                if (newQuadrant === 3)
                    newQuadrant = 2;
                else if (newQuadrant === 4)
                    newQuadrant = 1;
            }
            setQuadrant(newQuadrant);
        }
    }, [parentRef, width, height, defaultQuadrant, cwidth, cheight]);
    return quadrant;
}
function useClientRect() {
    var _a = react.useState(null), rect = _a[0], setRect = _a[1];
    var ref = react.useCallback(function (node) {
        if (node !== null && node instanceof Element) {
            setRect(node.getBoundingClientRect());
        }
    }, []);
    return [rect, ref];
}
function useHTMLElement() {
    var _a = react.useState(null), dom = _a[0], setDom = _a[1];
    var ref = react.useCallback(function (node) {
        if (node !== null && node instanceof HTMLElement) {
            setDom(node);
        }
    }, []);
    return [dom, ref];
}

exports.useClientRect = useClientRect;
exports.useDocumentEventListener = useDocumentEventListener;
exports.useEventListener = useEventListener;
exports.useHTMLElement = useHTMLElement;
exports.useOutsideClick = useOutsideClick;
exports.useQuadrant = useQuadrant;
exports.useTimeout = useTimeout;
exports.useToggle = useToggle;
exports.useWindowEventListener = useWindowEventListener;
exports.useWindowSize = useWindowSize;
//# sourceMappingURL=index.js.map
